pub struct DefiniteAssignmentResult {
pub states: AssignmentStateMap,
}Expand description
Definite assignment analysis result for a specific program point.
Fields
states: AssignmentStateMapAssignment states for all variables at this point
Implementations
Sourceimpl DefiniteAssignmentResult
impl DefiniteAssignmentResult
Sourcepub fn is_definitely_assigned(&self, var_id: NodeIndex) -> bool
pub fn is_definitely_assigned(&self, var_id: NodeIndex) -> bool
Check if a variable is definitely assigned at this point.
Sourcepub fn is_maybe_assigned(&self, var_id: NodeIndex) -> bool
pub fn is_maybe_assigned(&self, var_id: NodeIndex) -> bool
Check if a variable may be assigned at this point.