FlowGraphBuilder

Struct FlowGraphBuilder 

pub struct FlowGraphBuilder<'a> { /* private fields */ }
Builder for constructing a FlowGraph from Node AST.

The FlowGraphBuilder traverses the AST post-binding and constructs the control flow graph without mutating the AST nodes.

Implementations

Source

impl<'a> FlowGraphBuilder<'a>

pub fn new(arena: &'a NodeArena) -> Self

Create a new FlowGraphBuilder.

pub fn build_source_file(&mut self, statements: &NodeList) -> &FlowGraph

Build the flow graph for a source file.

pub fn build_flow_graph(&mut self, statements: &NodeList) -> &FlowGraph

Build the flow graph for a list of statements.

This is a general entry point that can be used for:

  • Source files
  • Function bodies
  • Block statements
  • Any list of statements

This is an alias for build_source_file() but with a more general name.

pub fn build_function_body(&mut self, body: &BlockData) -> &FlowGraph

Build the flow graph for a function body.

Entry point for building flow graphs for function bodies. Resets the builder state and creates a new START node for the function.

Arguments
  • body - The block statement representing the function body
Returns

Reference to the built flow graph

pub fn build_block(&mut self, block: &BlockData)

Build flow graph for a block.

Entry point for building flow graphs for block statements. Processes all statements in the block sequentially.

Arguments
  • block - The block statement to build flow graph for
pub const fn graph(&self) -> &FlowGraph

Get the flow graph being constructed.

pub fn into_graph(self) -> FlowGraph

Consume the builder and return the flow graph.